# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Networking.NetworkOperators")

try:
    import winsdk.windows.data.xml.dom
except ImportError:
    pass

try:
    import winsdk.windows.devices.sms
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.networking
except ImportError:
    pass

try:
    import winsdk.windows.networking.connectivity
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class DataClasses(enum.IntFlag):
    NONE = 0
    GPRS = 0x1
    EDGE = 0x2
    UMTS = 0x4
    HSDPA = 0x8
    HSUPA = 0x10
    LTE_ADVANCED = 0x20
    NEW_RADIO_NON_STANDALONE = 0x40
    NEW_RADIO_STANDALONE = 0x80
    CDMA1X_RTT = 0x10000
    CDMA1X_EVDO = 0x20000
    CDMA1X_EVDO_REV_A = 0x40000
    CDMA1X_EVDV = 0x80000
    CDMA3X_RTT = 0x100000
    CDMA1X_EVDO_REV_B = 0x200000
    CDMA_UMB = 0x400000
    CUSTOM = 0x80000000

class ESimAuthenticationPreference(enum.IntEnum):
    ON_ENTRY = 0
    ON_ACTION = 1
    NEVER = 2

class ESimDiscoverResultKind(enum.IntEnum):
    NONE = 0
    EVENTS = 1
    PROFILE_METADATA = 2

class ESimOperationStatus(enum.IntEnum):
    SUCCESS = 0
    NOT_AUTHORIZED = 1
    NOT_FOUND = 2
    POLICY_VIOLATION = 3
    INSUFFICIENT_SPACE_ON_CARD = 4
    SERVER_FAILURE = 5
    SERVER_NOT_REACHABLE = 6
    TIMEOUT_WAITING_FOR_USER_CONSENT = 7
    INCORRECT_CONFIRMATION_CODE = 8
    CONFIRMATION_CODE_MAX_RETRIES_EXCEEDED = 9
    CARD_REMOVED = 10
    CARD_BUSY = 11
    OTHER = 12
    CARD_GENERAL_FAILURE = 13
    CONFIRMATION_CODE_MISSING = 14
    INVALID_MATCHING_ID = 15
    NO_ELIGIBLE_PROFILE_FOR_THIS_DEVICE = 16
    OPERATION_ABORTED = 17
    EID_MISMATCH = 18
    PROFILE_NOT_AVAILABLE_FOR_NEW_BINDING = 19
    PROFILE_NOT_RELEASED_BY_OPERATOR = 20
    OPERATION_PROHIBITED_BY_PROFILE_CLASS = 21
    PROFILE_NOT_PRESENT = 22
    NO_CORRESPONDING_REQUEST = 23
    TIMEOUT_WAITING_FOR_RESPONSE = 24
    ICCID_ALREADY_EXISTS = 25
    PROFILE_PROCESSING_ERROR = 26
    SERVER_NOT_TRUSTED = 27
    PROFILE_DOWNLOAD_MAX_RETRIES_EXCEEDED = 28

class ESimProfileClass(enum.IntEnum):
    OPERATIONAL = 0
    TEST = 1
    PROVISIONING = 2

class ESimProfileMetadataState(enum.IntEnum):
    UNKNOWN = 0
    WAITING_FOR_INSTALL = 1
    DOWNLOADING = 2
    INSTALLING = 3
    EXPIRED = 4
    REJECTING_DOWNLOAD = 5
    NO_LONGER_AVAILABLE = 6
    DENIED_BY_POLICY = 7

class ESimProfileState(enum.IntEnum):
    UNKNOWN = 0
    DISABLED = 1
    ENABLED = 2
    DELETED = 3

class ESimState(enum.IntEnum):
    UNKNOWN = 0
    IDLE = 1
    REMOVED = 2
    BUSY = 3

class ESimWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    ENUMERATION_COMPLETED = 2
    STOPPING = 3
    STOPPED = 4

class HotspotAuthenticationResponseCode(enum.IntEnum):
    NO_ERROR = 0
    LOGIN_SUCCEEDED = 50
    LOGIN_FAILED = 100
    RADIUS_SERVER_ERROR = 102
    NETWORK_ADMINISTRATOR_ERROR = 105
    LOGIN_ABORTED = 151
    ACCESS_GATEWAY_INTERNAL_ERROR = 255

class MobileBroadbandAccountWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    ENUMERATION_COMPLETED = 2
    STOPPED = 3
    ABORTED = 4

class MobileBroadbandDeviceType(enum.IntEnum):
    UNKNOWN = 0
    EMBEDDED = 1
    REMOVABLE = 2
    REMOTE = 3

class MobileBroadbandModemStatus(enum.IntEnum):
    SUCCESS = 0
    OTHER_FAILURE = 1
    BUSY = 2
    NO_DEVICE_SUPPORT = 3

class MobileBroadbandPinFormat(enum.IntEnum):
    UNKNOWN = 0
    NUMERIC = 1
    ALPHANUMERIC = 2

class MobileBroadbandPinLockState(enum.IntEnum):
    UNKNOWN = 0
    UNLOCKED = 1
    PIN_REQUIRED = 2
    PIN_UNBLOCK_KEY_REQUIRED = 3

class MobileBroadbandPinType(enum.IntEnum):
    NONE = 0
    CUSTOM = 1
    PIN1 = 2
    PIN2 = 3
    SIM_PIN = 4
    FIRST_SIM_PIN = 5
    NETWORK_PIN = 6
    NETWORK_SUBSET_PIN = 7
    SERVICE_PROVIDER_PIN = 8
    CORPORATE_PIN = 9
    SUBSIDY_LOCK = 10

class MobileBroadbandRadioState(enum.IntEnum):
    OFF = 0
    ON = 1

class MobileBroadbandSlotState(enum.IntEnum):
    UNMANAGED = 0
    UNKNOWN = 1
    OFF_EMPTY = 2
    OFF = 3
    EMPTY = 4
    NOT_READY = 5
    ACTIVE = 6
    ERROR = 7
    ACTIVE_ESIM = 8
    ACTIVE_ESIM_NO_PROFILE = 9

class MobileBroadbandUiccAppOperationStatus(enum.IntEnum):
    SUCCESS = 0
    INVALID_UICC_FILE_PATH = 1
    ACCESS_CONDITION_NOT_HELD = 2
    UICC_BUSY = 3

class NetworkDeviceStatus(enum.IntEnum):
    DEVICE_NOT_READY = 0
    DEVICE_READY = 1
    SIM_NOT_INSERTED = 2
    BAD_SIM = 3
    DEVICE_HARDWARE_FAILURE = 4
    ACCOUNT_NOT_ACTIVATED = 5
    DEVICE_LOCKED = 6
    DEVICE_BLOCKED = 7

class NetworkOperatorDataUsageNotificationKind(enum.IntEnum):
    DATA_USAGE_PROGRESS = 0

class NetworkOperatorEventMessageType(enum.IntEnum):
    GSM = 0
    CDMA = 1
    USSD = 2
    DATA_PLAN_THRESHOLD_REACHED = 3
    DATA_PLAN_RESET = 4
    DATA_PLAN_DELETED = 5
    PROFILE_CONNECTED = 6
    PROFILE_DISCONNECTED = 7
    REGISTERED_ROAMING = 8
    REGISTERED_HOME = 9
    TETHERING_ENTITLEMENT_CHECK = 10
    TETHERING_OPERATIONAL_STATE_CHANGED = 11
    TETHERING_NUMBER_OF_CLIENTS_CHANGED = 12

class NetworkRegistrationState(enum.IntEnum):
    NONE = 0
    DEREGISTERED = 1
    SEARCHING = 2
    HOME = 3
    ROAMING = 4
    PARTNER = 5
    DENIED = 6

class ProfileMediaType(enum.IntEnum):
    WLAN = 0
    WWAN = 1

class TetheringCapability(enum.IntEnum):
    ENABLED = 0
    DISABLED_BY_GROUP_POLICY = 1
    DISABLED_BY_HARDWARE_LIMITATION = 2
    DISABLED_BY_OPERATOR = 3
    DISABLED_BY_SKU = 4
    DISABLED_BY_REQUIRED_APP_NOT_INSTALLED = 5
    DISABLED_DUE_TO_UNKNOWN_CAUSE = 6
    DISABLED_BY_SYSTEM_CAPABILITY = 7

class TetheringOperationStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN = 1
    MOBILE_BROADBAND_DEVICE_OFF = 2
    WI_FI_DEVICE_OFF = 3
    ENTITLEMENT_CHECK_TIMEOUT = 4
    ENTITLEMENT_CHECK_FAILURE = 5
    OPERATION_IN_PROGRESS = 6
    BLUETOOTH_DEVICE_OFF = 7
    NETWORK_LIMITED_CONNECTIVITY = 8

class TetheringOperationalState(enum.IntEnum):
    UNKNOWN = 0
    ON = 1
    OFF = 2
    IN_TRANSITION = 3

class TetheringWiFiBand(enum.IntEnum):
    AUTO = 0
    TWO_POINT_FOUR_GIGAHERTZ = 1
    FIVE_GIGAHERTZ = 2

class UiccAccessCondition(enum.IntEnum):
    ALWAYS_ALLOWED = 0
    PIN1 = 1
    PIN2 = 2
    PIN3 = 3
    PIN4 = 4
    ADMINISTRATIVE5 = 5
    ADMINISTRATIVE6 = 6
    NEVER_ALLOWED = 7

class UiccAppKind(enum.IntEnum):
    UNKNOWN = 0
    M_F = 1
    M_F_SIM = 2
    M_F_RUIM = 3
    U_SIM = 4
    C_SIM = 5
    I_SIM = 6

class UiccAppRecordKind(enum.IntEnum):
    UNKNOWN = 0
    TRANSPARENT = 1
    RECORD_ORIENTED = 2

class UssdResultCode(enum.IntEnum):
    NO_ACTION_REQUIRED = 0
    ACTION_REQUIRED = 1
    TERMINATED = 2
    OTHER_LOCAL_CLIENT = 3
    OPERATION_NOT_SUPPORTED = 4
    NETWORK_TIMEOUT = 5

_ns_module._register_DataClasses(DataClasses)
_ns_module._register_ESimAuthenticationPreference(ESimAuthenticationPreference)
_ns_module._register_ESimDiscoverResultKind(ESimDiscoverResultKind)
_ns_module._register_ESimOperationStatus(ESimOperationStatus)
_ns_module._register_ESimProfileClass(ESimProfileClass)
_ns_module._register_ESimProfileMetadataState(ESimProfileMetadataState)
_ns_module._register_ESimProfileState(ESimProfileState)
_ns_module._register_ESimState(ESimState)
_ns_module._register_ESimWatcherStatus(ESimWatcherStatus)
_ns_module._register_HotspotAuthenticationResponseCode(HotspotAuthenticationResponseCode)
_ns_module._register_MobileBroadbandAccountWatcherStatus(MobileBroadbandAccountWatcherStatus)
_ns_module._register_MobileBroadbandDeviceType(MobileBroadbandDeviceType)
_ns_module._register_MobileBroadbandModemStatus(MobileBroadbandModemStatus)
_ns_module._register_MobileBroadbandPinFormat(MobileBroadbandPinFormat)
_ns_module._register_MobileBroadbandPinLockState(MobileBroadbandPinLockState)
_ns_module._register_MobileBroadbandPinType(MobileBroadbandPinType)
_ns_module._register_MobileBroadbandRadioState(MobileBroadbandRadioState)
_ns_module._register_MobileBroadbandSlotState(MobileBroadbandSlotState)
_ns_module._register_MobileBroadbandUiccAppOperationStatus(MobileBroadbandUiccAppOperationStatus)
_ns_module._register_NetworkDeviceStatus(NetworkDeviceStatus)
_ns_module._register_NetworkOperatorDataUsageNotificationKind(NetworkOperatorDataUsageNotificationKind)
_ns_module._register_NetworkOperatorEventMessageType(NetworkOperatorEventMessageType)
_ns_module._register_NetworkRegistrationState(NetworkRegistrationState)
_ns_module._register_ProfileMediaType(ProfileMediaType)
_ns_module._register_TetheringCapability(TetheringCapability)
_ns_module._register_TetheringOperationStatus(TetheringOperationStatus)
_ns_module._register_TetheringOperationalState(TetheringOperationalState)
_ns_module._register_TetheringWiFiBand(TetheringWiFiBand)
_ns_module._register_UiccAccessCondition(UiccAccessCondition)
_ns_module._register_UiccAppKind(UiccAppKind)
_ns_module._register_UiccAppRecordKind(UiccAppRecordKind)
_ns_module._register_UssdResultCode(UssdResultCode)

ESimProfileInstallProgress = _ns_module.ESimProfileInstallProgress
ProfileUsage = _ns_module.ProfileUsage
ESim = _ns_module.ESim
ESimAddedEventArgs = _ns_module.ESimAddedEventArgs
ESimDiscoverEvent = _ns_module.ESimDiscoverEvent
ESimDiscoverResult = _ns_module.ESimDiscoverResult
ESimDownloadProfileMetadataResult = _ns_module.ESimDownloadProfileMetadataResult
ESimManager = _ns_module.ESimManager
ESimOperationResult = _ns_module.ESimOperationResult
ESimPolicy = _ns_module.ESimPolicy
ESimProfile = _ns_module.ESimProfile
ESimProfileMetadata = _ns_module.ESimProfileMetadata
ESimProfilePolicy = _ns_module.ESimProfilePolicy
ESimRemovedEventArgs = _ns_module.ESimRemovedEventArgs
ESimServiceInfo = _ns_module.ESimServiceInfo
ESimUpdatedEventArgs = _ns_module.ESimUpdatedEventArgs
ESimWatcher = _ns_module.ESimWatcher
FdnAccessManager = _ns_module.FdnAccessManager
HotspotAuthenticationContext = _ns_module.HotspotAuthenticationContext
HotspotAuthenticationEventDetails = _ns_module.HotspotAuthenticationEventDetails
HotspotCredentialsAuthenticationResult = _ns_module.HotspotCredentialsAuthenticationResult
KnownCSimFilePaths = _ns_module.KnownCSimFilePaths
KnownRuimFilePaths = _ns_module.KnownRuimFilePaths
KnownSimFilePaths = _ns_module.KnownSimFilePaths
KnownUSimFilePaths = _ns_module.KnownUSimFilePaths
MobileBroadbandAccount = _ns_module.MobileBroadbandAccount
MobileBroadbandAccountEventArgs = _ns_module.MobileBroadbandAccountEventArgs
MobileBroadbandAccountUpdatedEventArgs = _ns_module.MobileBroadbandAccountUpdatedEventArgs
MobileBroadbandAccountWatcher = _ns_module.MobileBroadbandAccountWatcher
MobileBroadbandAntennaSar = _ns_module.MobileBroadbandAntennaSar
MobileBroadbandCellCdma = _ns_module.MobileBroadbandCellCdma
MobileBroadbandCellGsm = _ns_module.MobileBroadbandCellGsm
MobileBroadbandCellLte = _ns_module.MobileBroadbandCellLte
MobileBroadbandCellNR = _ns_module.MobileBroadbandCellNR
MobileBroadbandCellTdscdma = _ns_module.MobileBroadbandCellTdscdma
MobileBroadbandCellUmts = _ns_module.MobileBroadbandCellUmts
MobileBroadbandCellsInfo = _ns_module.MobileBroadbandCellsInfo
MobileBroadbandCurrentSlotIndexChangedEventArgs = _ns_module.MobileBroadbandCurrentSlotIndexChangedEventArgs
MobileBroadbandDeviceInformation = _ns_module.MobileBroadbandDeviceInformation
MobileBroadbandDeviceService = _ns_module.MobileBroadbandDeviceService
MobileBroadbandDeviceServiceCommandResult = _ns_module.MobileBroadbandDeviceServiceCommandResult
MobileBroadbandDeviceServiceCommandSession = _ns_module.MobileBroadbandDeviceServiceCommandSession
MobileBroadbandDeviceServiceDataReceivedEventArgs = _ns_module.MobileBroadbandDeviceServiceDataReceivedEventArgs
MobileBroadbandDeviceServiceDataSession = _ns_module.MobileBroadbandDeviceServiceDataSession
MobileBroadbandDeviceServiceInformation = _ns_module.MobileBroadbandDeviceServiceInformation
MobileBroadbandDeviceServiceTriggerDetails = _ns_module.MobileBroadbandDeviceServiceTriggerDetails
MobileBroadbandModem = _ns_module.MobileBroadbandModem
MobileBroadbandModemConfiguration = _ns_module.MobileBroadbandModemConfiguration
MobileBroadbandModemIsolation = _ns_module.MobileBroadbandModemIsolation
MobileBroadbandNetwork = _ns_module.MobileBroadbandNetwork
MobileBroadbandNetworkRegistrationStateChange = _ns_module.MobileBroadbandNetworkRegistrationStateChange
MobileBroadbandNetworkRegistrationStateChangeTriggerDetails = _ns_module.MobileBroadbandNetworkRegistrationStateChangeTriggerDetails
MobileBroadbandPco = _ns_module.MobileBroadbandPco
MobileBroadbandPcoDataChangeTriggerDetails = _ns_module.MobileBroadbandPcoDataChangeTriggerDetails
MobileBroadbandPin = _ns_module.MobileBroadbandPin
MobileBroadbandPinLockStateChange = _ns_module.MobileBroadbandPinLockStateChange
MobileBroadbandPinLockStateChangeTriggerDetails = _ns_module.MobileBroadbandPinLockStateChangeTriggerDetails
MobileBroadbandPinManager = _ns_module.MobileBroadbandPinManager
MobileBroadbandPinOperationResult = _ns_module.MobileBroadbandPinOperationResult
MobileBroadbandRadioStateChange = _ns_module.MobileBroadbandRadioStateChange
MobileBroadbandRadioStateChangeTriggerDetails = _ns_module.MobileBroadbandRadioStateChangeTriggerDetails
MobileBroadbandSarManager = _ns_module.MobileBroadbandSarManager
MobileBroadbandSlotInfo = _ns_module.MobileBroadbandSlotInfo
MobileBroadbandSlotInfoChangedEventArgs = _ns_module.MobileBroadbandSlotInfoChangedEventArgs
MobileBroadbandSlotManager = _ns_module.MobileBroadbandSlotManager
MobileBroadbandTransmissionStateChangedEventArgs = _ns_module.MobileBroadbandTransmissionStateChangedEventArgs
MobileBroadbandUicc = _ns_module.MobileBroadbandUicc
MobileBroadbandUiccApp = _ns_module.MobileBroadbandUiccApp
MobileBroadbandUiccAppReadRecordResult = _ns_module.MobileBroadbandUiccAppReadRecordResult
MobileBroadbandUiccAppRecordDetailsResult = _ns_module.MobileBroadbandUiccAppRecordDetailsResult
MobileBroadbandUiccAppsResult = _ns_module.MobileBroadbandUiccAppsResult
NetworkOperatorDataUsageTriggerDetails = _ns_module.NetworkOperatorDataUsageTriggerDetails
NetworkOperatorNotificationEventDetails = _ns_module.NetworkOperatorNotificationEventDetails
NetworkOperatorTetheringAccessPointConfiguration = _ns_module.NetworkOperatorTetheringAccessPointConfiguration
NetworkOperatorTetheringClient = _ns_module.NetworkOperatorTetheringClient
NetworkOperatorTetheringManager = _ns_module.NetworkOperatorTetheringManager
NetworkOperatorTetheringOperationResult = _ns_module.NetworkOperatorTetheringOperationResult
ProvisionFromXmlDocumentResults = _ns_module.ProvisionFromXmlDocumentResults
ProvisionedProfile = _ns_module.ProvisionedProfile
ProvisioningAgent = _ns_module.ProvisioningAgent
TetheringEntitlementCheckTriggerDetails = _ns_module.TetheringEntitlementCheckTriggerDetails
UssdMessage = _ns_module.UssdMessage
UssdReply = _ns_module.UssdReply
UssdSession = _ns_module.UssdSession



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections

Self = typing.TypeVar('Self')

class CommunicationBlockingAccessManager(winsdk.system.Object):
    is_blocking_active: typing.ClassVar[winsdk.system.Boolean]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CommunicationBlockingAccessManager: ...
    @staticmethod
    def is_blocked_number_async(number: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    @staticmethod
    def show_block_numbers_u_i(phone_numbers: typing.Iterable[str]) -> winsdk.system.Boolean: ...
    @staticmethod
    def show_blocked_calls_u_i() -> None: ...
    @staticmethod
    def show_blocked_messages_u_i() -> None: ...
    @staticmethod
    def show_unblock_numbers_u_i(phone_numbers: typing.Iterable[str]) -> winsdk.system.Boolean: ...

class CommunicationBlockingAppManager(winsdk.system.Object):
    is_current_app_active_blocking_app: typing.ClassVar[winsdk.system.Boolean]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CommunicationBlockingAppManager: ...
    @staticmethod
    def request_set_as_active_blocking_app_async() -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    @staticmethod
    def show_communication_blocking_settings_u_i() -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Perception.Spatial.Surfaces")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.foundation.numerics
except ImportError:
    pass

try:
    import winsdk.windows.graphics.directx
except ImportError:
    pass

try:
    import winsdk.windows.perception.spatial
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass


SpatialSurfaceInfo = _ns_module.SpatialSurfaceInfo
SpatialSurfaceMesh = _ns_module.SpatialSurfaceMesh
SpatialSurfaceMeshBuffer = _ns_module.SpatialSurfaceMeshBuffer
SpatialSurfaceMeshOptions = _ns_module.SpatialSurfaceMeshOptions
SpatialSurfaceObserver = _ns_module.SpatialSurfaceObserver



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Services.Cortana")

try:
    import winsdk.windows.applicationmodel.datatransfer
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

class CortanaPermission(enum.IntEnum):
    BROWSING_HISTORY = 0
    CALENDAR = 1
    CALL_HISTORY = 2
    CONTACTS = 3
    EMAIL = 4
    INPUT_PERSONALIZATION = 5
    LOCATION = 6
    MESSAGING = 7
    MICROPHONE = 8
    PERSONALIZATION = 9
    PHONE_CALL = 10

class CortanaPermissionsChangeResult(enum.IntEnum):
    SUCCESS = 0
    UNAVAILABLE = 1
    DISABLED_BY_POLICY = 2

_ns_module._register_CortanaPermission(CortanaPermission)
_ns_module._register_CortanaPermissionsChangeResult(CortanaPermissionsChangeResult)

CortanaActionableInsights = _ns_module.CortanaActionableInsights
CortanaActionableInsightsOptions = _ns_module.CortanaActionableInsightsOptions
CortanaPermissionsManager = _ns_module.CortanaPermissionsManager
CortanaSettings = _ns_module.CortanaSettings



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.ui

Self = typing.TypeVar('Self')

class ResourceLoader(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ResourceLoader: ...
    @typing.overload
    def __new__(cls: typing.Type[ResourceLoader], name: str) -> ResourceLoader:...
    @typing.overload
    def __new__(cls: typing.Type[ResourceLoader]) -> ResourceLoader:...
    @staticmethod
    def get_default_pri_path(package_full_name: str) -> str: ...
    @typing.overload
    @staticmethod
    def get_for_current_view() -> typing.Optional[ResourceLoader]: ...
    @typing.overload
    @staticmethod
    def get_for_current_view(name: str) -> typing.Optional[ResourceLoader]: ...
    @staticmethod
    def get_for_u_i_context(context: typing.Optional[winsdk.windows.ui.UIContext]) -> typing.Optional[ResourceLoader]: ...
    @typing.overload
    @staticmethod
    def get_for_view_independent_use() -> typing.Optional[ResourceLoader]: ...
    @typing.overload
    @staticmethod
    def get_for_view_independent_use(name: str) -> typing.Optional[ResourceLoader]: ...
    def get_string(self, resource: str) -> str: ...
    @staticmethod
    def get_string_for_reference(uri: typing.Optional[winsdk.windows.foundation.Uri]) -> str: ...
    def get_string_for_uri(self, uri: typing.Optional[winsdk.windows.foundation.Uri]) -> str: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections

class MicrosoftAccountMultiFactorAuthenticationType(enum.IntEnum):
    USER = 0
    DEVICE = 1

class MicrosoftAccountMultiFactorServiceResponse(enum.IntEnum):
    SUCCESS = 0
    ERROR = 1
    NO_NETWORK_CONNECTION = 2
    SERVICE_UNAVAILABLE = 3
    TOTP_SETUP_DENIED = 4
    NGC_NOT_SETUP = 5
    SESSION_ALREADY_DENIED = 6
    SESSION_ALREADY_APPROVED = 7
    SESSION_EXPIRED = 8
    NGC_NONCE_EXPIRED = 9
    INVALID_SESSION_ID = 10
    INVALID_SESSION_TYPE = 11
    INVALID_OPERATION = 12
    INVALID_STATE_TRANSITION = 13
    DEVICE_NOT_FOUND = 14
    FLOW_DISABLED = 15
    SESSION_NOT_APPROVED = 16
    OPERATION_CANCELED_BY_USER = 17
    NGC_DISABLED_BY_SERVER = 18
    NGC_KEY_NOT_FOUND_ON_SERVER = 19
    U_I_REQUIRED = 20
    DEVICE_ID_CHANGED = 21

class MicrosoftAccountMultiFactorSessionApprovalStatus(enum.IntEnum):
    PENDING = 0
    APPROVED = 1
    DENIED = 2

class MicrosoftAccountMultiFactorSessionAuthenticationStatus(enum.IntEnum):
    AUTHENTICATED = 0
    UNAUTHENTICATED = 1

Self = typing.TypeVar('Self')

class MicrosoftAccountMultiFactorAuthenticationManager(winsdk.system.Object):
    current: typing.ClassVar[typing.Optional[MicrosoftAccountMultiFactorAuthenticationManager]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MicrosoftAccountMultiFactorAuthenticationManager: ...
    def add_device_async(self, user_account_id: str, authentication_token: str, wns_channel_id: str) -> winsdk.windows.foundation.IAsyncOperation[MicrosoftAccountMultiFactorServiceResponse]: ...
    @typing.overload
    def approve_session_async(self, session_authentiction_status: MicrosoftAccountMultiFactorSessionAuthenticationStatus, authentication_session_info: typing.Optional[MicrosoftAccountMultiFactorSessionInfo]) -> winsdk.windows.foundation.IAsyncOperation[MicrosoftAccountMultiFactorServiceResponse]: ...
    @typing.overload
    def approve_session_async(self, session_authentiction_status: MicrosoftAccountMultiFactorSessionAuthenticationStatus, user_account_id: str, session_id: str, session_authentication_type: MicrosoftAccountMultiFactorAuthenticationType) -> winsdk.windows.foundation.IAsyncOperation[MicrosoftAccountMultiFactorServiceResponse]: ...
    @typing.overload
    def deny_session_async(self, authentication_session_info: typing.Optional[MicrosoftAccountMultiFactorSessionInfo]) -> winsdk.windows.foundation.IAsyncOperation[MicrosoftAccountMultiFactorServiceResponse]: ...
    @typing.overload
    def deny_session_async(self, user_account_id: str, session_id: str, session_authentication_type: MicrosoftAccountMultiFactorAuthenticationType) -> winsdk.windows.foundation.IAsyncOperation[MicrosoftAccountMultiFactorServiceResponse]: ...
    def get_one_time_pass_code_async(self, user_account_id: str, code_length: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[MicrosoftAccountMultiFactorOneTimeCodedInfo]: ...
    def get_sessions_and_unregistered_accounts_async(self, user_account_id_list: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[MicrosoftAccountMultiFactorUnregisteredAccountsAndSessionInfo]: ...
    def get_sessions_async(self, user_account_id_list: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[MicrosoftAccountMultiFactorGetSessionsResult]: ...
    def remove_device_async(self, user_account_id: str) -> winsdk.windows.foundation.IAsyncOperation[MicrosoftAccountMultiFactorServiceResponse]: ...
    def update_wns_channel_async(self, user_account_id: str, channel_uri: str) -> winsdk.windows.foundation.IAsyncOperation[MicrosoftAccountMultiFactorServiceResponse]: ...

class MicrosoftAccountMultiFactorGetSessionsResult(winsdk.system.Object):
    service_response: MicrosoftAccountMultiFactorServiceResponse
    sessions: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MicrosoftAccountMultiFactorSessionInfo]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MicrosoftAccountMultiFactorGetSessionsResult: ...

class MicrosoftAccountMultiFactorOneTimeCodedInfo(winsdk.system.Object):
    code: str
    service_response: MicrosoftAccountMultiFactorServiceResponse
    time_interval: datetime.timedelta
    time_to_live: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MicrosoftAccountMultiFactorOneTimeCodedInfo: ...

class MicrosoftAccountMultiFactorSessionInfo(winsdk.system.Object):
    approval_status: MicrosoftAccountMultiFactorSessionApprovalStatus
    authentication_type: MicrosoftAccountMultiFactorAuthenticationType
    display_session_id: str
    expiration_time: datetime.datetime
    request_time: datetime.datetime
    session_id: str
    user_account_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MicrosoftAccountMultiFactorSessionInfo: ...

class MicrosoftAccountMultiFactorUnregisteredAccountsAndSessionInfo(winsdk.system.Object):
    service_response: MicrosoftAccountMultiFactorServiceResponse
    sessions: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MicrosoftAccountMultiFactorSessionInfo]]
    unregistered_accounts: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MicrosoftAccountMultiFactorUnregisteredAccountsAndSessionInfo: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.streams

class SecondaryAuthenticationFactorAuthenticationMessage(enum.IntEnum):
    INVALID = 0
    SWIPE_UP_WELCOME = 1
    TAP_WELCOME = 2
    DEVICE_NEEDS_ATTENTION = 3
    LOOKING_FOR_DEVICE = 4
    LOOKING_FOR_DEVICE_PLUGGEDIN = 5
    BLUETOOTH_IS_DISABLED = 6
    NFC_IS_DISABLED = 7
    WI_FI_IS_DISABLED = 8
    EXTRA_TAP_IS_REQUIRED = 9
    DISABLED_BY_POLICY = 10
    TAP_ON_DEVICE_REQUIRED = 11
    HOLD_FINGER = 12
    SCAN_FINGER = 13
    UNAUTHORIZED_USER = 14
    REREGISTER_REQUIRED = 15
    TRY_AGAIN = 16
    SAY_PASSPHRASE = 17
    READY_TO_SIGN_IN = 18
    USE_ANOTHER_SIGN_IN_OPTION = 19
    CONNECTION_REQUIRED = 20
    TIME_LIMIT_EXCEEDED = 21
    CANCELED_BY_USER = 22
    CENTER_HAND = 23
    MOVE_HAND_CLOSER = 24
    MOVE_HAND_FARTHER = 25
    PLACE_HAND_ABOVE = 26
    RECOGNITION_FAILED = 27
    DEVICE_UNAVAILABLE = 28

class SecondaryAuthenticationFactorAuthenticationScenario(enum.IntEnum):
    SIGN_IN = 0
    CREDENTIAL_PROMPT = 1

class SecondaryAuthenticationFactorAuthenticationStage(enum.IntEnum):
    NOT_STARTED = 0
    WAITING_FOR_USER_CONFIRMATION = 1
    COLLECTING_CREDENTIAL = 2
    SUSPENDING_AUTHENTICATION = 3
    CREDENTIAL_COLLECTED = 4
    CREDENTIAL_AUTHENTICATED = 5
    STOPPING_AUTHENTICATION = 6
    READY_FOR_LOCK = 7
    CHECKING_DEVICE_PRESENCE = 8

class SecondaryAuthenticationFactorAuthenticationStatus(enum.IntEnum):
    FAILED = 0
    STARTED = 1
    UNKNOWN_DEVICE = 2
    DISABLED_BY_POLICY = 3
    INVALID_AUTHENTICATION_STAGE = 4

class SecondaryAuthenticationFactorDeviceCapabilities(enum.IntFlag):
    NONE = 0
    SECURE_STORAGE = 0x1
    STORE_KEYS = 0x2
    CONFIRM_USER_INTENT_TO_AUTHENTICATE = 0x4
    SUPPORT_SECURE_USER_PRESENCE_CHECK = 0x8
    TRANSMITTED_DATA_IS_ENCRYPTED = 0x10
    H_MAC_SHA256 = 0x20
    CLOSE_RANGE_DATA_TRANSMISSION = 0x40

class SecondaryAuthenticationFactorDeviceFindScope(enum.IntEnum):
    USER = 0
    ALL_USERS = 1

class SecondaryAuthenticationFactorDevicePresence(enum.IntEnum):
    ABSENT = 0
    PRESENT = 1

class SecondaryAuthenticationFactorDevicePresenceMonitoringMode(enum.IntEnum):
    UNSUPPORTED = 0
    APP_MANAGED = 1
    SYSTEM_MANAGED = 2

class SecondaryAuthenticationFactorDevicePresenceMonitoringRegistrationStatus(enum.IntEnum):
    UNSUPPORTED = 0
    SUCCEEDED = 1
    DISABLED_BY_POLICY = 2

class SecondaryAuthenticationFactorFinishAuthenticationStatus(enum.IntEnum):
    FAILED = 0
    COMPLETED = 1
    NONCE_EXPIRED = 2

class SecondaryAuthenticationFactorRegistrationStatus(enum.IntEnum):
    FAILED = 0
    STARTED = 1
    CANCELED_BY_USER = 2
    PIN_SETUP_REQUIRED = 3
    DISABLED_BY_POLICY = 4

Self = typing.TypeVar('Self')

class SecondaryAuthenticationFactorAuthentication(winsdk.system.Object):
    device_configuration_data: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    device_nonce: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    service_authentication_hmac: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    session_nonce: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SecondaryAuthenticationFactorAuthentication: ...
    def abort_authentication_async(self, error_log_message: str) -> winsdk.windows.foundation.IAsyncAction: ...
    def finish_authentication_async(self, device_hmac: typing.Optional[winsdk.windows.storage.streams.IBuffer], session_hmac: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperation[SecondaryAuthenticationFactorFinishAuthenticationStatus]: ...
    @staticmethod
    def get_authentication_stage_info_async() -> winsdk.windows.foundation.IAsyncOperation[SecondaryAuthenticationFactorAuthenticationStageInfo]: ...
    @staticmethod
    def show_notification_message_async(device_name: str, message: SecondaryAuthenticationFactorAuthenticationMessage) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def start_authentication_async(device_id: str, service_authentication_nonce: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperation[SecondaryAuthenticationFactorAuthenticationResult]: ...
    @staticmethod
    def add_authentication_stage_changed(handler: winsdk.windows.foundation.EventHandler[SecondaryAuthenticationFactorAuthenticationStageChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_authentication_stage_changed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class SecondaryAuthenticationFactorAuthenticationResult(winsdk.system.Object):
    authentication: typing.Optional[SecondaryAuthenticationFactorAuthentication]
    status: SecondaryAuthenticationFactorAuthenticationStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SecondaryAuthenticationFactorAuthenticationResult: ...

class SecondaryAuthenticationFactorAuthenticationStageChangedEventArgs(winsdk.system.Object):
    stage_info: typing.Optional[SecondaryAuthenticationFactorAuthenticationStageInfo]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SecondaryAuthenticationFactorAuthenticationStageChangedEventArgs: ...

class SecondaryAuthenticationFactorAuthenticationStageInfo(winsdk.system.Object):
    device_id: str
    scenario: SecondaryAuthenticationFactorAuthenticationScenario
    stage: SecondaryAuthenticationFactorAuthenticationStage
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SecondaryAuthenticationFactorAuthenticationStageInfo: ...

class SecondaryAuthenticationFactorInfo(winsdk.system.Object):
    device_configuration_data: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    device_friendly_name: str
    device_id: str
    device_model_number: str
    is_authentication_supported: winsdk.system.Boolean
    presence_monitoring_mode: SecondaryAuthenticationFactorDevicePresenceMonitoringMode
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SecondaryAuthenticationFactorInfo: ...
    def update_device_presence_async(self, presence_state: SecondaryAuthenticationFactorDevicePresence) -> winsdk.windows.foundation.IAsyncAction: ...

class SecondaryAuthenticationFactorRegistration(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SecondaryAuthenticationFactorRegistration: ...
    def abort_registering_device_async(self, error_log_message: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def find_all_registered_device_info_async(query_type: SecondaryAuthenticationFactorDeviceFindScope) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[SecondaryAuthenticationFactorInfo]]: ...
    def finish_registering_device_async(self, device_configuration_data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def is_device_presence_monitoring_supported() -> winsdk.system.Boolean: ...
    @typing.overload
    @staticmethod
    def register_device_presence_monitoring_async(device_id: str, device_instance_path: str, monitoring_mode: SecondaryAuthenticationFactorDevicePresenceMonitoringMode) -> winsdk.windows.foundation.IAsyncOperation[SecondaryAuthenticationFactorDevicePresenceMonitoringRegistrationStatus]: ...
    @typing.overload
    @staticmethod
    def register_device_presence_monitoring_async(device_id: str, device_instance_path: str, monitoring_mode: SecondaryAuthenticationFactorDevicePresenceMonitoringMode, device_friendly_name: str, device_model_number: str, device_configuration_data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperation[SecondaryAuthenticationFactorDevicePresenceMonitoringRegistrationStatus]: ...
    @staticmethod
    def request_start_registering_device_async(device_id: str, capabilities: SecondaryAuthenticationFactorDeviceCapabilities, device_friendly_name: str, device_model_number: str, device_key: typing.Optional[winsdk.windows.storage.streams.IBuffer], mutual_authentication_key: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperation[SecondaryAuthenticationFactorRegistrationResult]: ...
    @staticmethod
    def unregister_device_async(device_id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def unregister_device_presence_monitoring_async(device_id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def update_device_configuration_data_async(device_id: str, device_configuration_data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncAction: ...

class SecondaryAuthenticationFactorRegistrationResult(winsdk.system.Object):
    registration: typing.Optional[SecondaryAuthenticationFactorRegistration]
    status: SecondaryAuthenticationFactorRegistrationStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SecondaryAuthenticationFactorRegistrationResult: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.system

class CredentialPromptType(enum.IntEnum):
    PROMPT_IF_NEEDED = 0
    RETYPE_CREDENTIALS = 1
    DO_NOT_PROMPT = 2

class OnlineIdSystemTicketStatus(enum.IntEnum):
    SUCCESS = 0
    ERROR = 1
    SERVICE_CONNECTION_ERROR = 2

Self = typing.TypeVar('Self')

class OnlineIdAuthenticator(winsdk.system.Object):
    application_id: winsdk.system.Guid
    authenticated_safe_customer_id: str
    can_sign_out: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> OnlineIdAuthenticator: ...
    def __new__(cls: typing.Type[OnlineIdAuthenticator]) -> OnlineIdAuthenticator:...
    @typing.overload
    def authenticate_user_async(self, request: typing.Optional[OnlineIdServiceTicketRequest]) -> UserAuthenticationOperation: ...
    @typing.overload
    def authenticate_user_async(self, requests: typing.Iterable[OnlineIdServiceTicketRequest], credential_prompt_type: CredentialPromptType) -> UserAuthenticationOperation: ...
    def sign_out_user_async(self) -> SignOutUserOperation: ...

class OnlineIdServiceTicket(winsdk.system.Object):
    error_code: winsdk.system.Int32
    request: typing.Optional[OnlineIdServiceTicketRequest]
    value: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> OnlineIdServiceTicket: ...

class OnlineIdServiceTicketRequest(winsdk.system.Object):
    policy: str
    service: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> OnlineIdServiceTicketRequest: ...
    @typing.overload
    def __new__(cls: typing.Type[OnlineIdServiceTicketRequest], service: str, policy: str) -> OnlineIdServiceTicketRequest:...
    @typing.overload
    def __new__(cls: typing.Type[OnlineIdServiceTicketRequest], service: str) -> OnlineIdServiceTicketRequest:...

class OnlineIdSystemAuthenticator(winsdk.system.Object):
    default: typing.ClassVar[typing.Optional[OnlineIdSystemAuthenticatorForUser]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> OnlineIdSystemAuthenticator: ...
    @staticmethod
    def get_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[OnlineIdSystemAuthenticatorForUser]: ...

class OnlineIdSystemAuthenticatorForUser(winsdk.system.Object):
    application_id: winsdk.system.Guid
    user: typing.Optional[winsdk.windows.system.User]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> OnlineIdSystemAuthenticatorForUser: ...
    def get_ticket_async(self, request: typing.Optional[OnlineIdServiceTicketRequest]) -> winsdk.windows.foundation.IAsyncOperation[OnlineIdSystemTicketResult]: ...

class OnlineIdSystemIdentity(winsdk.system.Object):
    id: str
    ticket: typing.Optional[OnlineIdServiceTicket]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> OnlineIdSystemIdentity: ...

class OnlineIdSystemTicketResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    identity: typing.Optional[OnlineIdSystemIdentity]
    status: OnlineIdSystemTicketStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> OnlineIdSystemTicketResult: ...

class SignOutUserOperation(winsdk.system.Object):
    error_code: winsdk.windows.foundation.HResult
    id: winsdk.system.UInt32
    status: winsdk.windows.foundation.AsyncStatus
    completed: typing.Optional[winsdk.windows.foundation.AsyncActionCompletedHandler]
    def __await__(self) -> typing.Generator[typing.Any, None, None]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SignOutUserOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> None: ...

class UserAuthenticationOperation(winsdk.system.Object):
    error_code: winsdk.windows.foundation.HResult
    id: winsdk.system.UInt32
    status: winsdk.windows.foundation.AsyncStatus
    completed: typing.Optional[winsdk.windows.foundation.AsyncOperationCompletedHandler[UserIdentity]]
    def __await__(self) -> typing.Generator[typing.Any, None, typing.Optional[UserIdentity]]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserAuthenticationOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> typing.Optional[UserIdentity]: ...

class UserIdentity(winsdk.system.Object):
    first_name: str
    id: str
    is_beta_account: winsdk.system.Boolean
    is_confirmed_p_c: winsdk.system.Boolean
    last_name: str
    safe_customer_id: str
    sign_in_name: str
    tickets: typing.Optional[winsdk.windows.foundation.collections.IVectorView[OnlineIdServiceTicket]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserIdentity: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.datatransfer
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.streams
import winsdk.windows.system
import winsdk.windows.ui
import winsdk.windows.ui.core
import winsdk.windows.web
import winsdk.windows.web.http
import winsdk.windows.web.ui

class WebViewControlAcceleratorKeyRoutingStage(enum.IntEnum):
    TUNNELING = 0
    BUBBLING = 1

class WebViewControlMoveFocusReason(enum.IntEnum):
    PROGRAMMATIC = 0
    NEXT = 1
    PREVIOUS = 2

class WebViewControlProcessCapabilityState(enum.IntEnum):
    DEFAULT = 0
    DISABLED = 1
    ENABLED = 2

Self = typing.TypeVar('Self')

class WebViewControl(winsdk.system.Object):
    scale: winsdk.system.Double
    is_visible: winsdk.system.Boolean
    bounds: winsdk.windows.foundation.Rect
    process: typing.Optional[WebViewControlProcess]
    source: typing.Optional[winsdk.windows.foundation.Uri]
    default_background_color: winsdk.windows.ui.Color
    can_go_back: winsdk.system.Boolean
    can_go_forward: winsdk.system.Boolean
    contains_full_screen_element: winsdk.system.Boolean
    deferred_permission_requests: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.web.ui.WebViewControlDeferredPermissionRequest]]
    document_title: str
    settings: typing.Optional[winsdk.windows.web.ui.WebViewControlSettings]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControl: ...
    def add_initialize_script(self, script: str) -> None: ...
    def build_local_stream_uri(self, content_identifier: str, relative_path: str) -> typing.Optional[winsdk.windows.foundation.Uri]: ...
    def capture_preview_to_stream_async(self, stream: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]) -> winsdk.windows.foundation.IAsyncAction: ...
    def capture_selected_content_to_data_package_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.applicationmodel.datatransfer.DataPackage]: ...
    def close(self) -> None: ...
    def get_deferred_permission_request_by_id(self, id: winsdk.system.UInt32) -> typing.Optional[winsdk.windows.web.ui.WebViewControlDeferredPermissionRequest]: ...
    def go_back(self) -> None: ...
    def go_forward(self) -> None: ...
    def invoke_script_async(self, script_name: str, arguments: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    def move_focus(self, reason: WebViewControlMoveFocusReason) -> None: ...
    def navigate(self, source: typing.Optional[winsdk.windows.foundation.Uri]) -> None: ...
    def navigate_to_local_stream_uri(self, source: typing.Optional[winsdk.windows.foundation.Uri], stream_resolver: typing.Optional[winsdk.windows.web.IUriToStreamResolver]) -> None: ...
    def navigate_to_string(self, text: str) -> None: ...
    def navigate_with_http_request_message(self, request_message: typing.Optional[winsdk.windows.web.http.HttpRequestMessage]) -> None: ...
    def refresh(self) -> None: ...
    def stop(self) -> None: ...
    def add_contains_full_screen_element_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_contains_full_screen_element_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_content_loading(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlContentLoadingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_content_loading(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_d_o_m_content_loaded(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlDOMContentLoadedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_d_o_m_content_loaded(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_frame_content_loading(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlContentLoadingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_content_loading(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_frame_d_o_m_content_loaded(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlDOMContentLoadedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_d_o_m_content_loaded(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_frame_navigation_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlNavigationCompletedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_navigation_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_frame_navigation_starting(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlNavigationStartingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_navigation_starting(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_long_running_script_detected(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlLongRunningScriptDetectedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_long_running_script_detected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_navigation_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlNavigationCompletedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_navigation_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_navigation_starting(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlNavigationStartingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_navigation_starting(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_new_window_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlNewWindowRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_new_window_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_permission_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlPermissionRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_permission_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_script_notify(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlScriptNotifyEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_script_notify(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_unsafe_content_warning_displaying(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_unsafe_content_warning_displaying(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_unsupported_uri_scheme_identified(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlUnsupportedUriSchemeIdentifiedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_unsupported_uri_scheme_identified(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_unviewable_content_identified(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlUnviewableContentIdentifiedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_unviewable_content_identified(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_web_resource_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlWebResourceRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_web_resource_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_accelerator_key_pressed(self, handler: winsdk.windows.foundation.TypedEventHandler[WebViewControl, WebViewControlAcceleratorKeyPressedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_accelerator_key_pressed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_move_focus_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[WebViewControl, WebViewControlMoveFocusRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_move_focus_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_got_focus(self, handler: winsdk.windows.foundation.TypedEventHandler[WebViewControl, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_lost_focus(self, handler: winsdk.windows.foundation.TypedEventHandler[WebViewControl, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class WebViewControlAcceleratorKeyPressedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    event_type: winsdk.windows.ui.core.CoreAcceleratorKeyEventType
    key_status: winsdk.windows.ui.core.CorePhysicalKeyStatus
    routing_stage: WebViewControlAcceleratorKeyRoutingStage
    virtual_key: winsdk.windows.system.VirtualKey
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlAcceleratorKeyPressedEventArgs: ...

class WebViewControlMoveFocusRequestedEventArgs(winsdk.system.Object):
    reason: WebViewControlMoveFocusReason
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlMoveFocusRequestedEventArgs: ...

class WebViewControlProcess(winsdk.system.Object):
    enterprise_id: str
    is_private_network_client_server_capability_enabled: winsdk.system.Boolean
    process_id: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlProcess: ...
    @typing.overload
    def __new__(cls: typing.Type[WebViewControlProcess], process_options: typing.Optional[WebViewControlProcessOptions]) -> WebViewControlProcess:...
    @typing.overload
    def __new__(cls: typing.Type[WebViewControlProcess]) -> WebViewControlProcess:...
    def create_web_view_control_async(self, host_window_handle: winsdk.system.Int64, bounds: winsdk.windows.foundation.Rect) -> winsdk.windows.foundation.IAsyncOperation[WebViewControl]: ...
    def get_web_view_controls(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[WebViewControl]]: ...
    def terminate(self) -> None: ...
    def add_process_exited(self, handler: winsdk.windows.foundation.TypedEventHandler[WebViewControlProcess, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_process_exited(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class WebViewControlProcessOptions(winsdk.system.Object):
    private_network_client_server_capability: WebViewControlProcessCapabilityState
    enterprise_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlProcessOptions: ...
    def __new__(cls: typing.Type[WebViewControlProcessOptions]) -> WebViewControlProcessOptions:...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.appointments
import winsdk.windows.applicationmodel.contacts
import winsdk.windows.applicationmodel.email
import winsdk.windows.applicationmodel.userdatatasks
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.streams
import winsdk.windows.system

class UserDataAccountContentKinds(enum.IntFlag):
    EMAIL = 0x1
    CONTACT = 0x2
    APPOINTMENT = 0x4

class UserDataAccountOtherAppReadAccess(enum.IntEnum):
    SYSTEM_ONLY = 0
    FULL = 1
    NONE = 2

class UserDataAccountStoreAccessType(enum.IntEnum):
    ALL_ACCOUNTS_READ_ONLY = 0
    APP_ACCOUNTS_READ_WRITE = 1

Self = typing.TypeVar('Self')

class UserDataAccount(winsdk.system.Object):
    user_display_name: str
    other_app_read_access: UserDataAccountOtherAppReadAccess
    icon: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    device_account_type_id: str
    id: str
    package_family_name: str
    is_protected_under_lock: winsdk.system.Boolean
    enterprise_id: str
    display_name: str
    explict_read_access_package_family_names: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    can_show_create_contact_group: winsdk.system.Boolean
    provider_properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataAccount: ...
    def delete_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def find_appointment_calendars_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.applicationmodel.appointments.AppointmentCalendar]]: ...
    def find_contact_annotation_lists_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.applicationmodel.contacts.ContactAnnotationList]]: ...
    def find_contact_groups_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.applicationmodel.contacts.ContactGroup]]: ...
    def find_contact_lists_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.applicationmodel.contacts.ContactList]]: ...
    def find_email_mailboxes_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.applicationmodel.email.EmailMailbox]]: ...
    def find_user_data_task_lists_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.applicationmodel.userdatatasks.UserDataTaskList]]: ...
    def save_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def try_show_create_contact_group_async(self) -> winsdk.windows.foundation.IAsyncOperation[str]: ...

class UserDataAccountManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataAccountManager: ...
    @staticmethod
    def get_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[UserDataAccountManagerForUser]: ...
    @staticmethod
    def request_store_async(store_access_type: UserDataAccountStoreAccessType) -> winsdk.windows.foundation.IAsyncOperation[UserDataAccountStore]: ...
    @staticmethod
    def show_account_error_resolver_async(id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def show_account_settings_async(id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def show_add_account_async(content_kinds: UserDataAccountContentKinds) -> winsdk.windows.foundation.IAsyncOperation[str]: ...

class UserDataAccountManagerForUser(winsdk.system.Object):
    user: typing.Optional[winsdk.windows.system.User]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataAccountManagerForUser: ...
    def request_store_async(self, store_access_type: UserDataAccountStoreAccessType) -> winsdk.windows.foundation.IAsyncOperation[UserDataAccountStore]: ...

class UserDataAccountStore(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataAccountStore: ...
    @typing.overload
    def create_account_async(self, user_display_name: str) -> winsdk.windows.foundation.IAsyncOperation[UserDataAccount]: ...
    @typing.overload
    def create_account_async(self, user_display_name: str, package_relative_app_id: str) -> winsdk.windows.foundation.IAsyncOperation[UserDataAccount]: ...
    @typing.overload
    def create_account_async(self, user_display_name: str, package_relative_app_id: str, enterprise_id: str) -> winsdk.windows.foundation.IAsyncOperation[UserDataAccount]: ...
    def find_accounts_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[UserDataAccount]]: ...
    def get_account_async(self, id: str) -> winsdk.windows.foundation.IAsyncOperation[UserDataAccount]: ...
    def add_store_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[UserDataAccountStore, UserDataAccountStoreChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_store_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class UserDataAccountStoreChangedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataAccountStoreChangedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system

Self = typing.TypeVar('Self')

class ClassicAppManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ClassicAppManager: ...
    @staticmethod
    def find_installed_app(app_uninstall_key: str) -> typing.Optional[InstalledClassicAppInfo]: ...

class InstalledClassicAppInfo(winsdk.system.Object):
    display_name: str
    display_version: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InstalledClassicAppInfo: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.gaming.input
import winsdk.windows.storage.streams

class GipFirmwareUpdateStatus(enum.IntEnum):
    COMPLETED = 0
    UP_TO_DATE = 1
    FAILED = 2

class GipMessageClass(enum.IntEnum):
    COMMAND = 0
    LOW_LATENCY = 1
    STANDARD_LATENCY = 2

class XusbDeviceSubtype(enum.IntEnum):
    UNKNOWN = 0
    GAMEPAD = 1
    ARCADE_PAD = 2
    ARCADE_STICK = 3
    FLIGHT_STICK = 4
    WHEEL = 5
    GUITAR = 6
    GUITAR_ALTERNATE = 7
    GUITAR_BASS = 8
    DRUM_KIT = 9
    DANCE_PAD = 10

class XusbDeviceType(enum.IntEnum):
    UNKNOWN = 0
    GAMEPAD = 1

Self = typing.TypeVar('Self')

class GameControllerVersionInfo:
    major: winsdk.system.UInt16
    minor: winsdk.system.UInt16
    build: winsdk.system.UInt16
    revision: winsdk.system.UInt16
    def __new__(cls: typing.Type[GameControllerVersionInfo], major: winsdk.system.UInt16, minor: winsdk.system.UInt16, build: winsdk.system.UInt16, revision: winsdk.system.UInt16) -> GameControllerVersionInfo: ...

class GipFirmwareUpdateProgress:
    percent_completed: winsdk.system.Double
    current_component_id: winsdk.system.UInt32
    def __new__(cls: typing.Type[GipFirmwareUpdateProgress], percent_completed: winsdk.system.Double, current_component_id: winsdk.system.UInt32) -> GipFirmwareUpdateProgress: ...

class GameControllerFactoryManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GameControllerFactoryManager: ...
    @staticmethod
    def register_custom_factory_for_gip_interface(factory: typing.Optional[ICustomGameControllerFactory], interface_id: winsdk.system.Guid) -> None: ...
    @staticmethod
    def register_custom_factory_for_hardware_id(factory: typing.Optional[ICustomGameControllerFactory], hardware_vendor_id: winsdk.system.UInt16, hardware_product_id: winsdk.system.UInt16) -> None: ...
    @staticmethod
    def register_custom_factory_for_xusb_type(factory: typing.Optional[ICustomGameControllerFactory], xusb_type: XusbDeviceType, xusb_subtype: XusbDeviceSubtype) -> None: ...
    @staticmethod
    def try_get_factory_controller_from_game_controller(factory: typing.Optional[ICustomGameControllerFactory], game_controller: typing.Optional[winsdk.windows.gaming.input.IGameController]) -> typing.Optional[winsdk.windows.gaming.input.IGameController]: ...

class GipFirmwareUpdateResult(winsdk.system.Object):
    extended_error_code: winsdk.system.UInt32
    final_component_id: winsdk.system.UInt32
    status: GipFirmwareUpdateStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GipFirmwareUpdateResult: ...

class GipGameControllerProvider(winsdk.system.Object):
    firmware_version_info: GameControllerVersionInfo
    hardware_product_id: winsdk.system.UInt16
    hardware_vendor_id: winsdk.system.UInt16
    hardware_version_info: GameControllerVersionInfo
    is_connected: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GipGameControllerProvider: ...
    def send_message(self, message_class: GipMessageClass, message_id: winsdk.system.UInt8, message_buffer: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def send_receive_message(self, message_class: GipMessageClass, message_id: winsdk.system.UInt8, request_message_buffer: winsdk.system.Array[winsdk.system.UInt8], response_message_buffer: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def update_firmware_async(self, firmware_image: typing.Optional[winsdk.windows.storage.streams.IInputStream]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[GipFirmwareUpdateResult, GipFirmwareUpdateProgress]: ...

class HidGameControllerProvider(winsdk.system.Object):
    firmware_version_info: GameControllerVersionInfo
    hardware_product_id: winsdk.system.UInt16
    hardware_vendor_id: winsdk.system.UInt16
    hardware_version_info: GameControllerVersionInfo
    is_connected: winsdk.system.Boolean
    usage_id: winsdk.system.UInt16
    usage_page: winsdk.system.UInt16
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HidGameControllerProvider: ...
    def get_feature_report(self, report_id: winsdk.system.UInt8, report_buffer: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def send_feature_report(self, report_id: winsdk.system.UInt8, report_buffer: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def send_output_report(self, report_id: winsdk.system.UInt8, report_buffer: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...

class XusbGameControllerProvider(winsdk.system.Object):
    firmware_version_info: GameControllerVersionInfo
    hardware_product_id: winsdk.system.UInt16
    hardware_vendor_id: winsdk.system.UInt16
    hardware_version_info: GameControllerVersionInfo
    is_connected: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XusbGameControllerProvider: ...
    def set_vibration(self, low_frequency_motor_speed: winsdk.system.Double, high_frequency_motor_speed: winsdk.system.Double) -> None: ...

class ICustomGameControllerFactory(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ICustomGameControllerFactory: ...
    def create_game_controller(self, provider: typing.Optional[IGameControllerProvider]) -> typing.Optional[winsdk.system.Object]: ...
    def on_game_controller_added(self, value: typing.Optional[winsdk.windows.gaming.input.IGameController]) -> None: ...
    def on_game_controller_removed(self, value: typing.Optional[winsdk.windows.gaming.input.IGameController]) -> None: ...

class IGameControllerInputSink(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IGameControllerInputSink: ...
    def on_input_resumed(self, timestamp: winsdk.system.UInt64) -> None: ...
    def on_input_suspended(self, timestamp: winsdk.system.UInt64) -> None: ...

class IGameControllerProvider(winsdk.system.Object):
    firmware_version_info: GameControllerVersionInfo
    hardware_product_id: winsdk.system.UInt16
    hardware_vendor_id: winsdk.system.UInt16
    hardware_version_info: GameControllerVersionInfo
    is_connected: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IGameControllerProvider: ...

class IGipGameControllerInputSink(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IGipGameControllerInputSink: ...
    def on_input_resumed(self, timestamp: winsdk.system.UInt64) -> None: ...
    def on_input_suspended(self, timestamp: winsdk.system.UInt64) -> None: ...
    def on_key_received(self, timestamp: winsdk.system.UInt64, key_code: winsdk.system.UInt8, is_pressed: winsdk.system.Boolean) -> None: ...
    def on_message_received(self, timestamp: winsdk.system.UInt64, message_class: GipMessageClass, message_id: winsdk.system.UInt8, sequence_id: winsdk.system.UInt8, message_buffer: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...

class IHidGameControllerInputSink(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IHidGameControllerInputSink: ...
    def on_input_report_received(self, timestamp: winsdk.system.UInt64, report_id: winsdk.system.UInt8, report_buffer: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def on_input_resumed(self, timestamp: winsdk.system.UInt64) -> None: ...
    def on_input_suspended(self, timestamp: winsdk.system.UInt64) -> None: ...

class IXusbGameControllerInputSink(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IXusbGameControllerInputSink: ...
    def on_input_received(self, timestamp: winsdk.system.UInt64, report_id: winsdk.system.UInt8, input_buffer: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def on_input_resumed(self, timestamp: winsdk.system.UInt64) -> None: ...
    def on_input_suspended(self, timestamp: winsdk.system.UInt64) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections

class VibrationAccessStatus(enum.IntEnum):
    ALLOWED = 0
    DENIED_BY_USER = 1
    DENIED_BY_SYSTEM = 2
    DENIED_BY_ENERGY_SAVER = 3

Self = typing.TypeVar('Self')

class KnownSimpleHapticsControllerWaveforms(winsdk.system.Object):
    buzz_continuous: typing.ClassVar[winsdk.system.UInt16]
    click: typing.ClassVar[winsdk.system.UInt16]
    press: typing.ClassVar[winsdk.system.UInt16]
    release: typing.ClassVar[winsdk.system.UInt16]
    rumble_continuous: typing.ClassVar[winsdk.system.UInt16]
    brush_continuous: typing.ClassVar[winsdk.system.UInt16]
    chisel_marker_continuous: typing.ClassVar[winsdk.system.UInt16]
    eraser_continuous: typing.ClassVar[winsdk.system.UInt16]
    error: typing.ClassVar[winsdk.system.UInt16]
    galaxy_pen_continuous: typing.ClassVar[winsdk.system.UInt16]
    hover: typing.ClassVar[winsdk.system.UInt16]
    ink_continuous: typing.ClassVar[winsdk.system.UInt16]
    marker_continuous: typing.ClassVar[winsdk.system.UInt16]
    pencil_continuous: typing.ClassVar[winsdk.system.UInt16]
    success: typing.ClassVar[winsdk.system.UInt16]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KnownSimpleHapticsControllerWaveforms: ...

class SimpleHapticsController(winsdk.system.Object):
    id: str
    is_intensity_supported: winsdk.system.Boolean
    is_play_count_supported: winsdk.system.Boolean
    is_play_duration_supported: winsdk.system.Boolean
    is_replay_pause_interval_supported: winsdk.system.Boolean
    supported_feedback: typing.Optional[winsdk.windows.foundation.collections.IVectorView[SimpleHapticsControllerFeedback]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SimpleHapticsController: ...
    @typing.overload
    def send_haptic_feedback(self, feedback: typing.Optional[SimpleHapticsControllerFeedback]) -> None: ...
    @typing.overload
    def send_haptic_feedback(self, feedback: typing.Optional[SimpleHapticsControllerFeedback], intensity: winsdk.system.Double) -> None: ...
    def send_haptic_feedback_for_duration(self, feedback: typing.Optional[SimpleHapticsControllerFeedback], intensity: winsdk.system.Double, play_duration: datetime.timedelta) -> None: ...
    def send_haptic_feedback_for_play_count(self, feedback: typing.Optional[SimpleHapticsControllerFeedback], intensity: winsdk.system.Double, play_count: winsdk.system.Int32, replay_pause_interval: datetime.timedelta) -> None: ...
    def stop_feedback(self) -> None: ...

class SimpleHapticsControllerFeedback(winsdk.system.Object):
    duration: datetime.timedelta
    waveform: winsdk.system.UInt16
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SimpleHapticsControllerFeedback: ...

class VibrationDevice(winsdk.system.Object):
    id: str
    simple_haptics_controller: typing.Optional[SimpleHapticsController]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VibrationDevice: ...
    @staticmethod
    def find_all_async() -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[VibrationDevice]]: ...
    @staticmethod
    def from_id_async(device_id: str) -> winsdk.windows.foundation.IAsyncOperation[VibrationDevice]: ...
    @staticmethod
    def get_default_async() -> winsdk.windows.foundation.IAsyncOperation[VibrationDevice]: ...
    @staticmethod
    def get_device_selector() -> str: ...
    @staticmethod
    def request_access_async() -> winsdk.windows.foundation.IAsyncOperation[VibrationAccessStatus]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.graphics.directx.direct3d11
import winsdk.windows.graphics.imaging
import winsdk.windows.media.core
import winsdk.windows.media.effects
import winsdk.windows.media.mediaproperties
import winsdk.windows.media.transcoding
import winsdk.windows.storage
import winsdk.windows.ui

class MediaTrimmingPreference(enum.IntEnum):
    FAST = 0
    PRECISE = 1

class VideoFramePrecision(enum.IntEnum):
    NEAREST_FRAME = 0
    NEAREST_KEY_FRAME = 1

Self = typing.TypeVar('Self')

class BackgroundAudioTrack(winsdk.system.Object):
    volume: winsdk.system.Double
    trim_time_from_start: datetime.timedelta
    trim_time_from_end: datetime.timedelta
    delay: datetime.timedelta
    audio_effect_definitions: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.media.effects.IAudioEffectDefinition]]
    original_duration: datetime.timedelta
    trimmed_duration: datetime.timedelta
    user_data: typing.Optional[winsdk.windows.foundation.collections.IMap[str, str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BackgroundAudioTrack: ...
    def clone(self) -> typing.Optional[BackgroundAudioTrack]: ...
    @staticmethod
    def create_from_embedded_audio_track(embedded_audio_track: typing.Optional[EmbeddedAudioTrack]) -> typing.Optional[BackgroundAudioTrack]: ...
    @staticmethod
    def create_from_file_async(file: typing.Optional[winsdk.windows.storage.IStorageFile]) -> winsdk.windows.foundation.IAsyncOperation[BackgroundAudioTrack]: ...
    def get_audio_encoding_properties(self) -> typing.Optional[winsdk.windows.media.mediaproperties.AudioEncodingProperties]: ...

class EmbeddedAudioTrack(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmbeddedAudioTrack: ...
    def get_audio_encoding_properties(self) -> typing.Optional[winsdk.windows.media.mediaproperties.AudioEncodingProperties]: ...

class MediaClip(winsdk.system.Object):
    selected_embedded_audio_track_index: winsdk.system.UInt32
    trim_time_from_end: datetime.timedelta
    volume: winsdk.system.Double
    trim_time_from_start: datetime.timedelta
    embedded_audio_tracks: typing.Optional[winsdk.windows.foundation.collections.IVectorView[EmbeddedAudioTrack]]
    end_time_in_composition: datetime.timedelta
    original_duration: datetime.timedelta
    start_time_in_composition: datetime.timedelta
    trimmed_duration: datetime.timedelta
    user_data: typing.Optional[winsdk.windows.foundation.collections.IMap[str, str]]
    video_effect_definitions: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.media.effects.IVideoEffectDefinition]]
    audio_effect_definitions: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.media.effects.IAudioEffectDefinition]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaClip: ...
    def clone(self) -> typing.Optional[MediaClip]: ...
    @staticmethod
    def create_from_color(color: winsdk.windows.ui.Color, original_duration: datetime.timedelta) -> typing.Optional[MediaClip]: ...
    @staticmethod
    def create_from_file_async(file: typing.Optional[winsdk.windows.storage.IStorageFile]) -> winsdk.windows.foundation.IAsyncOperation[MediaClip]: ...
    @staticmethod
    def create_from_image_file_async(file: typing.Optional[winsdk.windows.storage.IStorageFile], original_duration: datetime.timedelta) -> winsdk.windows.foundation.IAsyncOperation[MediaClip]: ...
    @staticmethod
    def create_from_surface(surface: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DSurface], original_duration: datetime.timedelta) -> typing.Optional[MediaClip]: ...
    def get_video_encoding_properties(self) -> typing.Optional[winsdk.windows.media.mediaproperties.VideoEncodingProperties]: ...

class MediaComposition(winsdk.system.Object):
    background_audio_tracks: typing.Optional[winsdk.windows.foundation.collections.IVector[BackgroundAudioTrack]]
    clips: typing.Optional[winsdk.windows.foundation.collections.IVector[MediaClip]]
    duration: datetime.timedelta
    user_data: typing.Optional[winsdk.windows.foundation.collections.IMap[str, str]]
    overlay_layers: typing.Optional[winsdk.windows.foundation.collections.IVector[MediaOverlayLayer]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaComposition: ...
    def __new__(cls: typing.Type[MediaComposition]) -> MediaComposition:...
    def clone(self) -> typing.Optional[MediaComposition]: ...
    def create_default_encoding_profile(self) -> typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile]: ...
    @typing.overload
    def generate_media_stream_source(self) -> typing.Optional[winsdk.windows.media.core.MediaStreamSource]: ...
    @typing.overload
    def generate_media_stream_source(self, encoding_profile: typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile]) -> typing.Optional[winsdk.windows.media.core.MediaStreamSource]: ...
    def generate_preview_media_stream_source(self, scaled_width: winsdk.system.Int32, scaled_height: winsdk.system.Int32) -> typing.Optional[winsdk.windows.media.core.MediaStreamSource]: ...
    def get_thumbnail_async(self, time_from_start: datetime.timedelta, scaled_width: winsdk.system.Int32, scaled_height: winsdk.system.Int32, frame_precision: VideoFramePrecision) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.graphics.imaging.ImageStream]: ...
    def get_thumbnails_async(self, times_from_start: typing.Iterable[datetime.timedelta], scaled_width: winsdk.system.Int32, scaled_height: winsdk.system.Int32, frame_precision: VideoFramePrecision) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.graphics.imaging.ImageStream]]: ...
    @staticmethod
    def load_async(file: typing.Optional[winsdk.windows.storage.StorageFile]) -> winsdk.windows.foundation.IAsyncOperation[MediaComposition]: ...
    @typing.overload
    def render_to_file_async(self, destination: typing.Optional[winsdk.windows.storage.IStorageFile]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.windows.media.transcoding.TranscodeFailureReason, winsdk.system.Double]: ...
    @typing.overload
    def render_to_file_async(self, destination: typing.Optional[winsdk.windows.storage.IStorageFile], trimming_preference: MediaTrimmingPreference) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.windows.media.transcoding.TranscodeFailureReason, winsdk.system.Double]: ...
    @typing.overload
    def render_to_file_async(self, destination: typing.Optional[winsdk.windows.storage.IStorageFile], trimming_preference: MediaTrimmingPreference, encoding_profile: typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.windows.media.transcoding.TranscodeFailureReason, winsdk.system.Double]: ...
    def save_async(self, file: typing.Optional[winsdk.windows.storage.IStorageFile]) -> winsdk.windows.foundation.IAsyncAction: ...

class MediaOverlay(winsdk.system.Object):
    position: winsdk.windows.foundation.Rect
    opacity: winsdk.system.Double
    delay: datetime.timedelta
    audio_enabled: winsdk.system.Boolean
    clip: typing.Optional[MediaClip]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaOverlay: ...
    @typing.overload
    def __new__(cls: typing.Type[MediaOverlay], clip: typing.Optional[MediaClip]) -> MediaOverlay:...
    @typing.overload
    def __new__(cls: typing.Type[MediaOverlay], clip: typing.Optional[MediaClip], position: winsdk.windows.foundation.Rect, opacity: winsdk.system.Double) -> MediaOverlay:...
    def clone(self) -> typing.Optional[MediaOverlay]: ...

class MediaOverlayLayer(winsdk.system.Object):
    custom_compositor_definition: typing.Optional[winsdk.windows.media.effects.IVideoCompositorDefinition]
    overlays: typing.Optional[winsdk.windows.foundation.collections.IVector[MediaOverlay]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaOverlayLayer: ...
    @typing.overload
    def __new__(cls: typing.Type[MediaOverlayLayer], compositor_definition: typing.Optional[winsdk.windows.media.effects.IVideoCompositorDefinition]) -> MediaOverlayLayer:...
    @typing.overload
    def __new__(cls: typing.Type[MediaOverlayLayer]) -> MediaOverlayLayer:...
    def clone(self) -> typing.Optional[MediaOverlayLayer]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Spi")

try:
    import winsdk.windows.devices.spi.provider
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class SpiMode(enum.IntEnum):
    MODE0 = 0
    MODE1 = 1
    MODE2 = 2
    MODE3 = 3

class SpiSharingMode(enum.IntEnum):
    EXCLUSIVE = 0
    SHARED = 1

_ns_module._register_SpiMode(SpiMode)
_ns_module._register_SpiSharingMode(SpiSharingMode)

SpiBusInfo = _ns_module.SpiBusInfo
SpiConnectionSettings = _ns_module.SpiConnectionSettings
SpiController = _ns_module.SpiController
SpiDevice = _ns_module.SpiDevice
ISpiDeviceStatics = _ns_module.ISpiDeviceStatics



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.graphics
import winsdk.windows.graphics.directx.direct3d11
import winsdk.windows.graphics.imaging
import winsdk.windows.media
import winsdk.windows.storage
import winsdk.windows.storage.streams

class LearningModelDeviceKind(enum.IntEnum):
    DEFAULT = 0
    CPU = 1
    DIRECT_X = 2
    DIRECT_X_HIGH_PERFORMANCE = 3
    DIRECT_X_MIN_POWER = 4

class LearningModelFeatureKind(enum.IntEnum):
    TENSOR = 0
    SEQUENCE = 1
    MAP = 2
    IMAGE = 3

class LearningModelPixelRange(enum.IntEnum):
    ZERO_TO255 = 0
    ZERO_TO_ONE = 1
    MINUS_ONE_TO_ONE = 2

class TensorKind(enum.IntEnum):
    UNDEFINED = 0
    FLOAT = 1
    UINT8 = 2
    INT8 = 3
    UINT16 = 4
    INT16 = 5
    INT32 = 6
    INT64 = 7
    STRING = 8
    BOOLEAN = 9
    FLOAT16 = 10
    DOUBLE = 11
    UINT32 = 12
    UINT64 = 13
    COMPLEX64 = 14
    COMPLEX128 = 15

Self = typing.TypeVar('Self')

class ImageFeatureDescriptor(winsdk.system.Object):
    bitmap_alpha_mode: winsdk.windows.graphics.imaging.BitmapAlphaMode
    bitmap_pixel_format: winsdk.windows.graphics.imaging.BitmapPixelFormat
    height: winsdk.system.UInt32
    width: winsdk.system.UInt32
    pixel_range: LearningModelPixelRange
    description: str
    is_required: winsdk.system.Boolean
    kind: LearningModelFeatureKind
    name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ImageFeatureDescriptor: ...

class ImageFeatureValue(winsdk.system.Object):
    video_frame: typing.Optional[winsdk.windows.media.VideoFrame]
    kind: LearningModelFeatureKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ImageFeatureValue: ...
    @staticmethod
    def create_from_video_frame(image: typing.Optional[winsdk.windows.media.VideoFrame]) -> typing.Optional[ImageFeatureValue]: ...

class LearningModel(winsdk.system.Object):
    author: str
    description: str
    domain: str
    input_features: typing.Optional[winsdk.windows.foundation.collections.IVectorView[ILearningModelFeatureDescriptor]]
    metadata: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, str]]
    name: str
    output_features: typing.Optional[winsdk.windows.foundation.collections.IVectorView[ILearningModelFeatureDescriptor]]
    version: winsdk.system.Int64
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LearningModel: ...
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def load_from_file_path(file_path: str) -> typing.Optional[LearningModel]: ...
    @typing.overload
    @staticmethod
    def load_from_file_path(file_path: str, operator_provider: typing.Optional[ILearningModelOperatorProvider]) -> typing.Optional[LearningModel]: ...
    @typing.overload
    @staticmethod
    def load_from_storage_file_async(model_file: typing.Optional[winsdk.windows.storage.IStorageFile]) -> winsdk.windows.foundation.IAsyncOperation[LearningModel]: ...
    @typing.overload
    @staticmethod
    def load_from_storage_file_async(model_file: typing.Optional[winsdk.windows.storage.IStorageFile], operator_provider: typing.Optional[ILearningModelOperatorProvider]) -> winsdk.windows.foundation.IAsyncOperation[LearningModel]: ...
    @typing.overload
    @staticmethod
    def load_from_stream(model_stream: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]) -> typing.Optional[LearningModel]: ...
    @typing.overload
    @staticmethod
    def load_from_stream(model_stream: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference], operator_provider: typing.Optional[ILearningModelOperatorProvider]) -> typing.Optional[LearningModel]: ...
    @typing.overload
    @staticmethod
    def load_from_stream_async(model_stream: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]) -> winsdk.windows.foundation.IAsyncOperation[LearningModel]: ...
    @typing.overload
    @staticmethod
    def load_from_stream_async(model_stream: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference], operator_provider: typing.Optional[ILearningModelOperatorProvider]) -> winsdk.windows.foundation.IAsyncOperation[LearningModel]: ...

class LearningModelBinding(winsdk.system.Object, typing.Mapping[str, winsdk.system.Object]):
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[str]: ...
    def __contains__(self, key: object) -> bool:...
    def __getitem__(self, key: str) -> winsdk.system.Object: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LearningModelBinding: ...
    def __new__(cls: typing.Type[LearningModelBinding], session: typing.Optional[LearningModelSession]) -> LearningModelBinding:...
    @typing.overload
    def bind(self, name: str, value: typing.Optional[winsdk.system.Object]) -> None: ...
    @typing.overload
    def bind(self, name: str, value: typing.Optional[winsdk.system.Object], props: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> None: ...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.system.Object]]]: ...
    def has_key(self, key: str) -> winsdk.system.Boolean: ...
    def lookup(self, key: str) -> typing.Optional[winsdk.system.Object]: ...
    def split(self) -> typing.Tuple[typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]], typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]]]: ...

class LearningModelDevice(winsdk.system.Object):
    adapter_id: winsdk.windows.graphics.DisplayAdapterId
    direct3_d11_device: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DDevice]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LearningModelDevice: ...
    def __new__(cls: typing.Type[LearningModelDevice], device_kind: LearningModelDeviceKind) -> LearningModelDevice:...
    @staticmethod
    def create_from_direct3_d11_device(device: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DDevice]) -> typing.Optional[LearningModelDevice]: ...

class LearningModelEvaluationResult(winsdk.system.Object):
    correlation_id: str
    error_status: winsdk.system.Int32
    outputs: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]]
    succeeded: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LearningModelEvaluationResult: ...

class LearningModelSession(winsdk.system.Object):
    device: typing.Optional[LearningModelDevice]
    evaluation_properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    model: typing.Optional[LearningModel]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LearningModelSession: ...
    @typing.overload
    def __new__(cls: typing.Type[LearningModelSession], model: typing.Optional[LearningModel], device_to_run_on: typing.Optional[LearningModelDevice], learning_model_session_options: typing.Optional[LearningModelSessionOptions]) -> LearningModelSession:...
    @typing.overload
    def __new__(cls: typing.Type[LearningModelSession], model: typing.Optional[LearningModel]) -> LearningModelSession:...
    @typing.overload
    def __new__(cls: typing.Type[LearningModelSession], model: typing.Optional[LearningModel], device_to_run_on: typing.Optional[LearningModelDevice]) -> LearningModelSession:...
    def close(self) -> None: ...
    def evaluate(self, bindings: typing.Optional[LearningModelBinding], correlation_id: str) -> typing.Optional[LearningModelEvaluationResult]: ...
    def evaluate_async(self, bindings: typing.Optional[LearningModelBinding], correlation_id: str) -> winsdk.windows.foundation.IAsyncOperation[LearningModelEvaluationResult]: ...
    def evaluate_features(self, features: winsdk.windows.foundation.collections.IMap[str, winsdk.system.Object], correlation_id: str) -> typing.Optional[LearningModelEvaluationResult]: ...
    def evaluate_features_async(self, features: winsdk.windows.foundation.collections.IMap[str, winsdk.system.Object], correlation_id: str) -> winsdk.windows.foundation.IAsyncOperation[LearningModelEvaluationResult]: ...

class LearningModelSessionOptions(winsdk.system.Object):
    batch_size_override: winsdk.system.UInt32
    close_model_on_session_creation: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LearningModelSessionOptions: ...
    def __new__(cls: typing.Type[LearningModelSessionOptions]) -> LearningModelSessionOptions:...
    def override_named_dimension(self, name: str, dimension: winsdk.system.UInt32) -> None: ...

class MapFeatureDescriptor(winsdk.system.Object):
    description: str
    is_required: winsdk.system.Boolean
    kind: LearningModelFeatureKind
    name: str
    key_kind: TensorKind
    value_descriptor: typing.Optional[ILearningModelFeatureDescriptor]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MapFeatureDescriptor: ...

class SequenceFeatureDescriptor(winsdk.system.Object):
    description: str
    is_required: winsdk.system.Boolean
    kind: LearningModelFeatureKind
    name: str
    element_descriptor: typing.Optional[ILearningModelFeatureDescriptor]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SequenceFeatureDescriptor: ...

class TensorBoolean(winsdk.system.Object):
    kind: LearningModelFeatureKind
    shape: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]
    tensor_kind: TensorKind
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TensorBoolean: ...
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create() -> typing.Optional[TensorBoolean]: ...
    @typing.overload
    @staticmethod
    def create(shape: typing.Iterable[winsdk.system.Int64]) -> typing.Optional[TensorBoolean]: ...
    @staticmethod
    def create_from_array(shape: typing.Iterable[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.Boolean]) -> typing.Optional[TensorBoolean]: ...
    @staticmethod
    def create_from_buffer(shape: winsdk.system.Array[winsdk.system.Int64], buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[TensorBoolean]: ...
    @staticmethod
    def create_from_iterable(shape: typing.Iterable[winsdk.system.Int64], data: typing.Iterable[winsdk.system.Boolean]) -> typing.Optional[TensorBoolean]: ...
    @staticmethod
    def create_from_shape_array_and_data_array(shape: winsdk.system.Array[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.Boolean]) -> typing.Optional[TensorBoolean]: ...
    def create_reference(self) -> typing.Optional[winsdk.windows.foundation.IMemoryBufferReference]: ...
    def get_as_vector_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Boolean]]: ...

class TensorDouble(winsdk.system.Object):
    kind: LearningModelFeatureKind
    shape: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]
    tensor_kind: TensorKind
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TensorDouble: ...
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create() -> typing.Optional[TensorDouble]: ...
    @typing.overload
    @staticmethod
    def create(shape: typing.Iterable[winsdk.system.Int64]) -> typing.Optional[TensorDouble]: ...
    @staticmethod
    def create_from_array(shape: typing.Iterable[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.Double]) -> typing.Optional[TensorDouble]: ...
    @staticmethod
    def create_from_buffer(shape: winsdk.system.Array[winsdk.system.Int64], buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[TensorDouble]: ...
    @staticmethod
    def create_from_iterable(shape: typing.Iterable[winsdk.system.Int64], data: typing.Iterable[winsdk.system.Double]) -> typing.Optional[TensorDouble]: ...
    @staticmethod
    def create_from_shape_array_and_data_array(shape: winsdk.system.Array[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.Double]) -> typing.Optional[TensorDouble]: ...
    def create_reference(self) -> typing.Optional[winsdk.windows.foundation.IMemoryBufferReference]: ...
    def get_as_vector_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Double]]: ...

class TensorFeatureDescriptor(winsdk.system.Object):
    description: str
    is_required: winsdk.system.Boolean
    kind: LearningModelFeatureKind
    name: str
    shape: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]
    tensor_kind: TensorKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TensorFeatureDescriptor: ...

class TensorFloat(winsdk.system.Object):
    kind: LearningModelFeatureKind
    shape: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]
    tensor_kind: TensorKind
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TensorFloat: ...
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create() -> typing.Optional[TensorFloat]: ...
    @typing.overload
    @staticmethod
    def create(shape: typing.Iterable[winsdk.system.Int64]) -> typing.Optional[TensorFloat]: ...
    @staticmethod
    def create_from_array(shape: typing.Iterable[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.Single]) -> typing.Optional[TensorFloat]: ...
    @staticmethod
    def create_from_buffer(shape: winsdk.system.Array[winsdk.system.Int64], buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[TensorFloat]: ...
    @staticmethod
    def create_from_iterable(shape: typing.Iterable[winsdk.system.Int64], data: typing.Iterable[winsdk.system.Single]) -> typing.Optional[TensorFloat]: ...
    @staticmethod
    def create_from_shape_array_and_data_array(shape: winsdk.system.Array[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.Single]) -> typing.Optional[TensorFloat]: ...
    def create_reference(self) -> typing.Optional[winsdk.windows.foundation.IMemoryBufferReference]: ...
    def get_as_vector_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Single]]: ...

class TensorFloat16Bit(winsdk.system.Object):
    kind: LearningModelFeatureKind
    shape: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]
    tensor_kind: TensorKind
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TensorFloat16Bit: ...
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create() -> typing.Optional[TensorFloat16Bit]: ...
    @typing.overload
    @staticmethod
    def create(shape: typing.Iterable[winsdk.system.Int64]) -> typing.Optional[TensorFloat16Bit]: ...
    @staticmethod
    def create_from_array(shape: typing.Iterable[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.Single]) -> typing.Optional[TensorFloat16Bit]: ...
    @staticmethod
    def create_from_buffer(shape: winsdk.system.Array[winsdk.system.Int64], buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[TensorFloat16Bit]: ...
    @staticmethod
    def create_from_iterable(shape: typing.Iterable[winsdk.system.Int64], data: typing.Iterable[winsdk.system.Single]) -> typing.Optional[TensorFloat16Bit]: ...
    @staticmethod
    def create_from_shape_array_and_data_array(shape: winsdk.system.Array[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.Single]) -> typing.Optional[TensorFloat16Bit]: ...
    def create_reference(self) -> typing.Optional[winsdk.windows.foundation.IMemoryBufferReference]: ...
    def get_as_vector_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Single]]: ...

class TensorInt16Bit(winsdk.system.Object):
    kind: LearningModelFeatureKind
    shape: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]
    tensor_kind: TensorKind
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TensorInt16Bit: ...
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create() -> typing.Optional[TensorInt16Bit]: ...
    @typing.overload
    @staticmethod
    def create(shape: typing.Iterable[winsdk.system.Int64]) -> typing.Optional[TensorInt16Bit]: ...
    @staticmethod
    def create_from_array(shape: typing.Iterable[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.Int16]) -> typing.Optional[TensorInt16Bit]: ...
    @staticmethod
    def create_from_buffer(shape: winsdk.system.Array[winsdk.system.Int64], buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[TensorInt16Bit]: ...
    @staticmethod
    def create_from_iterable(shape: typing.Iterable[winsdk.system.Int64], data: typing.Iterable[winsdk.system.Int16]) -> typing.Optional[TensorInt16Bit]: ...
    @staticmethod
    def create_from_shape_array_and_data_array(shape: winsdk.system.Array[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.Int16]) -> typing.Optional[TensorInt16Bit]: ...
    def create_reference(self) -> typing.Optional[winsdk.windows.foundation.IMemoryBufferReference]: ...
    def get_as_vector_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int16]]: ...

class TensorInt32Bit(winsdk.system.Object):
    kind: LearningModelFeatureKind
    shape: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]
    tensor_kind: TensorKind
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TensorInt32Bit: ...
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create() -> typing.Optional[TensorInt32Bit]: ...
    @typing.overload
    @staticmethod
    def create(shape: typing.Iterable[winsdk.system.Int64]) -> typing.Optional[TensorInt32Bit]: ...
    @staticmethod
    def create_from_array(shape: typing.Iterable[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.Int32]) -> typing.Optional[TensorInt32Bit]: ...
    @staticmethod
    def create_from_buffer(shape: winsdk.system.Array[winsdk.system.Int64], buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[TensorInt32Bit]: ...
    @staticmethod
    def create_from_iterable(shape: typing.Iterable[winsdk.system.Int64], data: typing.Iterable[winsdk.system.Int32]) -> typing.Optional[TensorInt32Bit]: ...
    @staticmethod
    def create_from_shape_array_and_data_array(shape: winsdk.system.Array[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.Int32]) -> typing.Optional[TensorInt32Bit]: ...
    def create_reference(self) -> typing.Optional[winsdk.windows.foundation.IMemoryBufferReference]: ...
    def get_as_vector_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int32]]: ...

class TensorInt64Bit(winsdk.system.Object):
    kind: LearningModelFeatureKind
    shape: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]
    tensor_kind: TensorKind
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TensorInt64Bit: ...
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create() -> typing.Optional[TensorInt64Bit]: ...
    @typing.overload
    @staticmethod
    def create(shape: typing.Iterable[winsdk.system.Int64]) -> typing.Optional[TensorInt64Bit]: ...
    @staticmethod
    def create_from_array(shape: typing.Iterable[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.Int64]) -> typing.Optional[TensorInt64Bit]: ...
    @staticmethod
    def create_from_buffer(shape: winsdk.system.Array[winsdk.system.Int64], buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[TensorInt64Bit]: ...
    @staticmethod
    def create_from_iterable(shape: typing.Iterable[winsdk.system.Int64], data: typing.Iterable[winsdk.system.Int64]) -> typing.Optional[TensorInt64Bit]: ...
    @staticmethod
    def create_from_shape_array_and_data_array(shape: winsdk.system.Array[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.Int64]) -> typing.Optional[TensorInt64Bit]: ...
    def create_reference(self) -> typing.Optional[winsdk.windows.foundation.IMemoryBufferReference]: ...
    def get_as_vector_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]: ...

class TensorInt8Bit(winsdk.system.Object):
    kind: LearningModelFeatureKind
    shape: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]
    tensor_kind: TensorKind
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TensorInt8Bit: ...
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create() -> typing.Optional[TensorInt8Bit]: ...
    @typing.overload
    @staticmethod
    def create(shape: typing.Iterable[winsdk.system.Int64]) -> typing.Optional[TensorInt8Bit]: ...
    @staticmethod
    def create_from_array(shape: typing.Iterable[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.UInt8]) -> typing.Optional[TensorInt8Bit]: ...
    @staticmethod
    def create_from_buffer(shape: winsdk.system.Array[winsdk.system.Int64], buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[TensorInt8Bit]: ...
    @staticmethod
    def create_from_iterable(shape: typing.Iterable[winsdk.system.Int64], data: typing.Iterable[winsdk.system.UInt8]) -> typing.Optional[TensorInt8Bit]: ...
    @staticmethod
    def create_from_shape_array_and_data_array(shape: winsdk.system.Array[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.UInt8]) -> typing.Optional[TensorInt8Bit]: ...
    def create_reference(self) -> typing.Optional[winsdk.windows.foundation.IMemoryBufferReference]: ...
    def get_as_vector_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt8]]: ...

class TensorString(winsdk.system.Object):
    kind: LearningModelFeatureKind
    shape: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]
    tensor_kind: TensorKind
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TensorString: ...
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create() -> typing.Optional[TensorString]: ...
    @typing.overload
    @staticmethod
    def create(shape: typing.Iterable[winsdk.system.Int64]) -> typing.Optional[TensorString]: ...
    @staticmethod
    def create_from_array(shape: typing.Iterable[winsdk.system.Int64], data: winsdk.system.Array[str]) -> typing.Optional[TensorString]: ...
    @staticmethod
    def create_from_iterable(shape: typing.Iterable[winsdk.system.Int64], data: typing.Iterable[str]) -> typing.Optional[TensorString]: ...
    @staticmethod
    def create_from_shape_array_and_data_array(shape: winsdk.system.Array[winsdk.system.Int64], data: winsdk.system.Array[str]) -> typing.Optional[TensorString]: ...
    def create_reference(self) -> typing.Optional[winsdk.windows.foundation.IMemoryBufferReference]: ...
    def get_as_vector_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]: ...

class TensorUInt16Bit(winsdk.system.Object):
    kind: LearningModelFeatureKind
    shape: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]
    tensor_kind: TensorKind
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TensorUInt16Bit: ...
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create() -> typing.Optional[TensorUInt16Bit]: ...
    @typing.overload
    @staticmethod
    def create(shape: typing.Iterable[winsdk.system.Int64]) -> typing.Optional[TensorUInt16Bit]: ...
    @staticmethod
    def create_from_array(shape: typing.Iterable[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.UInt16]) -> typing.Optional[TensorUInt16Bit]: ...
    @staticmethod
    def create_from_buffer(shape: winsdk.system.Array[winsdk.system.Int64], buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[TensorUInt16Bit]: ...
    @staticmethod
    def create_from_iterable(shape: typing.Iterable[winsdk.system.Int64], data: typing.Iterable[winsdk.system.UInt16]) -> typing.Optional[TensorUInt16Bit]: ...
    @staticmethod
    def create_from_shape_array_and_data_array(shape: winsdk.system.Array[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.UInt16]) -> typing.Optional[TensorUInt16Bit]: ...
    def create_reference(self) -> typing.Optional[winsdk.windows.foundation.IMemoryBufferReference]: ...
    def get_as_vector_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt16]]: ...

class TensorUInt32Bit(winsdk.system.Object):
    kind: LearningModelFeatureKind
    shape: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]
    tensor_kind: TensorKind
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TensorUInt32Bit: ...
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create() -> typing.Optional[TensorUInt32Bit]: ...
    @typing.overload
    @staticmethod
    def create(shape: typing.Iterable[winsdk.system.Int64]) -> typing.Optional[TensorUInt32Bit]: ...
    @staticmethod
    def create_from_array(shape: typing.Iterable[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.UInt32]) -> typing.Optional[TensorUInt32Bit]: ...
    @staticmethod
    def create_from_buffer(shape: winsdk.system.Array[winsdk.system.Int64], buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[TensorUInt32Bit]: ...
    @staticmethod
    def create_from_iterable(shape: typing.Iterable[winsdk.system.Int64], data: typing.Iterable[winsdk.system.UInt32]) -> typing.Optional[TensorUInt32Bit]: ...
    @staticmethod
    def create_from_shape_array_and_data_array(shape: winsdk.system.Array[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.UInt32]) -> typing.Optional[TensorUInt32Bit]: ...
    def create_reference(self) -> typing.Optional[winsdk.windows.foundation.IMemoryBufferReference]: ...
    def get_as_vector_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt32]]: ...

class TensorUInt64Bit(winsdk.system.Object):
    kind: LearningModelFeatureKind
    shape: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]
    tensor_kind: TensorKind
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TensorUInt64Bit: ...
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create() -> typing.Optional[TensorUInt64Bit]: ...
    @typing.overload
    @staticmethod
    def create(shape: typing.Iterable[winsdk.system.Int64]) -> typing.Optional[TensorUInt64Bit]: ...
    @staticmethod
    def create_from_array(shape: typing.Iterable[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.UInt64]) -> typing.Optional[TensorUInt64Bit]: ...
    @staticmethod
    def create_from_buffer(shape: winsdk.system.Array[winsdk.system.Int64], buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[TensorUInt64Bit]: ...
    @staticmethod
    def create_from_iterable(shape: typing.Iterable[winsdk.system.Int64], data: typing.Iterable[winsdk.system.UInt64]) -> typing.Optional[TensorUInt64Bit]: ...
    @staticmethod
    def create_from_shape_array_and_data_array(shape: winsdk.system.Array[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.UInt64]) -> typing.Optional[TensorUInt64Bit]: ...
    def create_reference(self) -> typing.Optional[winsdk.windows.foundation.IMemoryBufferReference]: ...
    def get_as_vector_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt64]]: ...

class TensorUInt8Bit(winsdk.system.Object):
    kind: LearningModelFeatureKind
    shape: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]
    tensor_kind: TensorKind
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TensorUInt8Bit: ...
    def close(self) -> None: ...
    @typing.overload
    @staticmethod
    def create() -> typing.Optional[TensorUInt8Bit]: ...
    @typing.overload
    @staticmethod
    def create(shape: typing.Iterable[winsdk.system.Int64]) -> typing.Optional[TensorUInt8Bit]: ...
    @staticmethod
    def create_from_array(shape: typing.Iterable[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.UInt8]) -> typing.Optional[TensorUInt8Bit]: ...
    @staticmethod
    def create_from_buffer(shape: winsdk.system.Array[winsdk.system.Int64], buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[TensorUInt8Bit]: ...
    @staticmethod
    def create_from_iterable(shape: typing.Iterable[winsdk.system.Int64], data: typing.Iterable[winsdk.system.UInt8]) -> typing.Optional[TensorUInt8Bit]: ...
    @staticmethod
    def create_from_shape_array_and_data_array(shape: winsdk.system.Array[winsdk.system.Int64], data: winsdk.system.Array[winsdk.system.UInt8]) -> typing.Optional[TensorUInt8Bit]: ...
    def create_reference(self) -> typing.Optional[winsdk.windows.foundation.IMemoryBufferReference]: ...
    def get_as_vector_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt8]]: ...

class ILearningModelFeatureDescriptor(winsdk.system.Object):
    description: str
    is_required: winsdk.system.Boolean
    kind: LearningModelFeatureKind
    name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ILearningModelFeatureDescriptor: ...

class ILearningModelFeatureValue(winsdk.system.Object):
    kind: LearningModelFeatureKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ILearningModelFeatureValue: ...

class ILearningModelOperatorProvider(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ILearningModelOperatorProvider: ...

class ITensor(winsdk.system.Object):
    shape: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int64]]
    tensor_kind: TensorKind
    kind: LearningModelFeatureKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ITensor: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.media

Self = typing.TypeVar('Self')

class SoundLevelBroker(winsdk.system.Object):
    sound_level: typing.ClassVar[winsdk.windows.media.SoundLevel]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SoundLevelBroker: ...
    @staticmethod
    def add_sound_level_changed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_sound_level_changed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.ViewManagement.Core")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

class CoreInputViewKind(enum.IntEnum):
    DEFAULT = 0
    KEYBOARD = 1
    HANDWRITING = 2
    EMOJI = 3
    SYMBOLS = 4
    CLIPBOARD = 5
    DICTATION = 6

class CoreInputViewOcclusionKind(enum.IntEnum):
    DOCKED = 0
    FLOATING = 1
    OVERLAY = 2

class CoreInputViewXYFocusTransferDirection(enum.IntEnum):
    UP = 0
    RIGHT = 1
    DOWN = 2
    LEFT = 3

_ns_module._register_CoreInputViewKind(CoreInputViewKind)
_ns_module._register_CoreInputViewOcclusionKind(CoreInputViewOcclusionKind)
_ns_module._register_CoreInputViewXYFocusTransferDirection(CoreInputViewXYFocusTransferDirection)

CoreFrameworkInputView = _ns_module.CoreFrameworkInputView
CoreFrameworkInputViewAnimationStartingEventArgs = _ns_module.CoreFrameworkInputViewAnimationStartingEventArgs
CoreFrameworkInputViewOcclusionsChangedEventArgs = _ns_module.CoreFrameworkInputViewOcclusionsChangedEventArgs
CoreInputView = _ns_module.CoreInputView
CoreInputViewAnimationStartingEventArgs = _ns_module.CoreInputViewAnimationStartingEventArgs
CoreInputViewHidingEventArgs = _ns_module.CoreInputViewHidingEventArgs
CoreInputViewOcclusion = _ns_module.CoreInputViewOcclusion
CoreInputViewOcclusionsChangedEventArgs = _ns_module.CoreInputViewOcclusionsChangedEventArgs
CoreInputViewShowingEventArgs = _ns_module.CoreInputViewShowingEventArgs
CoreInputViewTransferringXYFocusEventArgs = _ns_module.CoreInputViewTransferringXYFocusEventArgs
UISettingsController = _ns_module.UISettingsController



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.userdatatasks
import winsdk.windows.foundation

Self = typing.TypeVar('Self')

class UserDataTaskDataProviderConnection(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataTaskDataProviderConnection: ...
    def start(self) -> None: ...
    def add_complete_task_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[UserDataTaskDataProviderConnection, UserDataTaskListCompleteTaskRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_complete_task_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_create_or_update_task_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[UserDataTaskDataProviderConnection, UserDataTaskListCreateOrUpdateTaskRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_create_or_update_task_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_delete_task_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[UserDataTaskDataProviderConnection, UserDataTaskListDeleteTaskRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_delete_task_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_skip_occurrence_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[UserDataTaskDataProviderConnection, UserDataTaskListSkipOccurrenceRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_skip_occurrence_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_sync_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[UserDataTaskDataProviderConnection, UserDataTaskListSyncManagerSyncRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_sync_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class UserDataTaskDataProviderTriggerDetails(winsdk.system.Object):
    connection: typing.Optional[UserDataTaskDataProviderConnection]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataTaskDataProviderTriggerDetails: ...

class UserDataTaskListCompleteTaskRequest(winsdk.system.Object):
    task_id: str
    task_list_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataTaskListCompleteTaskRequest: ...
    def report_completed_async(self, completed_task_id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class UserDataTaskListCompleteTaskRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[UserDataTaskListCompleteTaskRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataTaskListCompleteTaskRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class UserDataTaskListCreateOrUpdateTaskRequest(winsdk.system.Object):
    task: typing.Optional[winsdk.windows.applicationmodel.userdatatasks.UserDataTask]
    task_list_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataTaskListCreateOrUpdateTaskRequest: ...
    def report_completed_async(self, created_or_updated_user_data_task: typing.Optional[winsdk.windows.applicationmodel.userdatatasks.UserDataTask]) -> winsdk.windows.foundation.IAsyncAction: ...
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class UserDataTaskListCreateOrUpdateTaskRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[UserDataTaskListCreateOrUpdateTaskRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataTaskListCreateOrUpdateTaskRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class UserDataTaskListDeleteTaskRequest(winsdk.system.Object):
    task_id: str
    task_list_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataTaskListDeleteTaskRequest: ...
    def report_completed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class UserDataTaskListDeleteTaskRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[UserDataTaskListDeleteTaskRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataTaskListDeleteTaskRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class UserDataTaskListSkipOccurrenceRequest(winsdk.system.Object):
    task_id: str
    task_list_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataTaskListSkipOccurrenceRequest: ...
    def report_completed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class UserDataTaskListSkipOccurrenceRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[UserDataTaskListSkipOccurrenceRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataTaskListSkipOccurrenceRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class UserDataTaskListSyncManagerSyncRequest(winsdk.system.Object):
    task_list_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataTaskListSyncManagerSyncRequest: ...
    def report_completed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class UserDataTaskListSyncManagerSyncRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[UserDataTaskListSyncManagerSyncRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataTaskListSyncManagerSyncRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

